--- loncom/lonnet/perl/lonnet.pm	2002/05/16 20:25:12	1.221
+++ loncom/lonnet/perl/lonnet.pm	2002/05/17 19:52:42	1.224
@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # TCP networking package
 #
-# $Id: lonnet.pm,v 1.221 2002/05/16 20:25:12 matthew Exp $
+# $Id: lonnet.pm,v 1.224 2002/05/17 19:52:42 albertel Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -491,7 +491,6 @@ sub homeserver {
         next if (exists($badhomecache{$index}->{$tryserver}));
 	if ($hostdom{$tryserver} eq $udom) {
            my $answer=reply("home:$udom:$uname",$tryserver);
-           my @tmp =keys(%{$badhomecache{$index}}); 
            if ($answer eq 'found') { 
               $homecache{$index}=$tryserver;
               return $tryserver; 
@@ -2805,12 +2804,12 @@ sub goodbye {
 }
 
 BEGIN {
 # ------------------------------------------- Read access.conf and loncapa.conf
 # (eventually access.conf will become deprecated)
     unless ($readit) {
 
 {
-    my $config=Apache::File->new("/etc/httpd/conf/access.conf");
+    my $config=Apache::File->new("/etc/httpd/conf/loncapa_apache.conf");
 
     while (my $configline=<$config>) {
         if ($configline =~ /^[^\#]*PerlSetVar/) {
@@ -3304,7 +3303,7 @@ replicates and subscribes to the file
 =item *
 
 filelocation($dir,$file) : returns file system location of a file based on URI;
-meant to be "fairly clean" absolute reference
+meant to be "fairly clean" absolute reference, $dir is a directory that relative $file lookups are to looked in ($dir of /a/dir and a file of ../bob will become /a/bob)
 
 =item *
@@ -2805,12 +2804,12 @@ sub goodbye {
 
 BEGIN {
-# ------------------------------------------- Read access.conf and loncapa.conf
+# ---------------------------------- Read loncapa_apache.conf and loncapa.conf
 # (eventually access.conf will become deprecated)
     unless ($readit) {